@@ -1,7 +1,8 @@
 #!/usr/bin/perl -w
 
 use strict;
-
+use File::Temp qw/ tempdir /;
+use File::Spec;
 =head1 VARIABLES
 
 =head2 @SupportedDrivers
@@ -76,13 +77,31 @@ sub connect_handle
 	goto &$call;
 }
 
-sub connect_sqlite
+=head2 connect_handle_with_driver($handle, $driver)
+
+Connects C<$handle> using driver C<$driver>; can use this to test the
+magic that turns a C<DBIx::SearchBuilder::Handle> into a C<DBIx::SearchBuilder::Handle::Foo>
+on C<Connect>.
+
+=cut
+
+sub connect_handle_with_driver
 {
-	my $handle = shift;
-	return $handle->Connect(
-		Driver => 'SQLite',
-		Database => File::Spec->catfile(File::Spec->tmpdir(), "sb-test.$$")
-	);
+	my $call = "connect_". lc $_[1];
+	return unless defined &$call;
+	@_ = $_[0];
+	goto &$call;
+}
+
+sub connect_sqlite {
+
+    my $dir = tempdir(CLEANUP => 1);
+    
+    my $handle = shift;
+    return $handle->Connect(
+        Driver   => 'SQLite',
+        Database => File::Spec->catfile($dir => "db.sqlite")
+    );
 }
 
 sub connect_mysql
@@ -92,10 +111,34 @@ sub connect_mysql
 		Driver => 'mysql',
 		Database => $ENV{'SB_TEST_MYSQL'},
 		User => $ENV{'SB_TEST_MYSQL_USER'} || 'root',
-		Pass => $ENV{'SB_TEST_MYSQL_PASS'} || '',
+		Password => $ENV{'SB_TEST_MYSQL_PASS'} || '',
 	);
 }
 
+sub connect_pg
+{
+	my $handle = shift;
+	return $handle->Connect(
+		Driver => 'Pg',
+		Database => $ENV{'SB_TEST_PG'},
+		User => $ENV{'SB_TEST_PG_USER'} || 'postgres',
+		Password => $ENV{'SB_TEST_PG_PASS'} || '',
+	);
+}
+
+sub connect_oracle
+{
+	my $handle = shift;
+	return $handle->Connect(
+		Driver   => 'Oracle',
+		Database => $ENV{'SB_TEST_ORACLE'},
+		Host     => $ENV{'SB_TEST_ORACLE_HOST'},
+		SID      => $ENV{'SB_TEST_ORACLE_SID'},
+		User     => $ENV{'SB_TEST_ORACLE_USER'} || 'test',
+		Password => $ENV{'SB_TEST_ORACLE_PASS'} || 'test',
+    );
+}
+
 =head2 should_test
 
 Checks environment for C<SB_TEST_*> variables.
@@ -150,7 +193,7 @@ sub init_schema
 
 =head2 cleanup_schema
 
-Takes C<$class> and C<$handle> and inits schema by calling
+Takes C<$class> and C<$handle> and cleanup schema by calling
 C<cleanup_schema_$driver> method of the C<$class> if method exists.
 Always returns undef.
 
@@ -168,4 +211,27 @@ sub cleanup_schema
 	}
 }
 
+=head2 init_data
+
+=cut
+
+sub init_data
+{
+	my ($class, $handle) = @_;
+	my @data = $class->init_data();
+	my @columns = @{ shift @data };
+	my $count = 0;
+	foreach my $values ( @data ) {
+		my %args;
+		for( my $i = 0; $i < @columns; $i++ ) {
+			$args{ $columns[$i] } = $values->[$i];
+		}
+		my $rec = $class->new( $handle );
+		my $id = $rec->Create( %args );
+		die "Couldn't create record" unless $id;
+		$count++;
+	}
+	return $count;
+}
+
 1;
